@@ -24,8 +24,8 @@ type fakeInfoOpRetVal struct {
 const TestImagesDir = "../../tests/images"
 
 const (
-	SmallActualSize  = 1024
-	SmallVirtualSize = 1024
+	SmallActualSize  = 1024 * 1024
+	SmallVirtualSize = 1024 * 1024
 )
 
 var (
@@ -243,9 +243,10 @@ var _ = Describe("Data Processor", func() {
 			url:              url,
 		}
 		dp := NewDataProcessor(mdp, "", "dataDir", tmpDir, "1G", 0.055, false)
-		dp.availableSpace = int64(1500)
+		dp.availableSpace = int64(1536000)
 		usableSpace := dp.getUsableSpace()
-		qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(usableSpace, 0))
+
+		qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(usableSpace, 1024*1024))
 		replaceQEMUOperations(qemuOperations, func() {
 			err = dp.ProcessData()
 			Expect(err).ToNot(HaveOccurred())
@@ -255,6 +256,7 @@ var _ = Describe("Data Processor", func() {
 			Expect(tmpDir).To(Equal(mdp.transferPath))
 		})
 	})
+
 })
 
 var _ = Describe("Convert", func() {
@@ -414,9 +416,9 @@ var _ = Describe("ResizeImage", func() {
 			}
 		})
 	},
-		table.Entry("successfully resize to imageSize when imageSize > info.VirtualSize and < totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1500), 0)), "1500", int64(2048), false),
-		table.Entry("successfully resize to totalSize when imageSize > info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "2500", int64(2048), false),
-		table.Entry("successfully do nothing when imageSize = info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1024), 0)), "1024", int64(1024), false),
+		table.Entry("successfully resize to imageSize when imageSize > info.VirtualSize and < totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1500*1024), 0)), "1536000", int64(2048*1024), false),
+		table.Entry("successfully resize to totalSize when imageSize > info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048*1024), 0)), "2560000", int64(2048*1024), false),
+		table.Entry("successfully do nothing when imageSize = info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1024*1024), 0)), "1048576", int64(1024*1024), false),
 		table.Entry("fail to resize to with blank imageSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "", int64(2048), true),
 		table.Entry("fail to resize to with blank imageSize", NewQEMUAllErrors(), "", int64(2048), true),
 	)
@@ -457,13 +459,13 @@ func (o *fakeQEMUOperations) ConvertToRawStream(*url.URL, string, bool) error {
 	return o.e2
 }
 
-func (o *fakeQEMUOperations) Validate(*url.URL, int64, float64) error {
+func (o *fakeQEMUOperations) Validate(*url.URL, int64) error {
 	return o.e5
 }
 
 func (o *fakeQEMUOperations) Resize(dest string, size resource.Quantity, preallocate bool) error {
 	if o.resizeQuantity != nil {
-		Expect(o.resizeQuantity.Cmp(size)).To(Equal(0))
+		Expect(o.resizeQuantity.Cmp(size)).To(Equal(0), "sizes don't match %v, %v", o.resizeQuantity.String(), size.String())
 	}
 	return o.e3
 }
